@@ -100,6 +100,9 @@ struct _GWebIface {
 
     gboolean (*web_set_pref) (GWeb *self, gpointer type, const gchar* name, gpointer value);
     gboolean (*web_get_pref) (GWeb *self, gpointer type, const gchar* name, gpointer value);
+
+    gboolean (*web_set_glist_select_item) (GWeb *self, gint select);
+    gboolean (*web_get_glist_item) (GWeb *self, guint index, gchar **username);
     
     GWebTransferItem* (*new_web_transfer_item) (GWeb *self, const gchar* url, const gchar* filename);
     GWebTransferItem* (*initialize_web_transfer_item) (GWeb *self, GObject *web_transfer_item);
@@ -189,6 +192,22 @@ struct _GWebIface {
 GType g_web_get_type (void);
 //gboolean g_web_set_pref (GWeb *self, gpointer type, gchar* name, gpointer value);
 //gboolean g_web_get_pref (GWeb *self, gpointer type, gchar* name, gpointer value);
+
+/** Set user name select item in glist.
+ * @param self Object pointer
+ * @param select item index
+ * @@return TRUE, if get the user name. FALSE, if not
+ */
+gboolean g_web_set_glist_select_item(GWeb *self, gint select);
+
+/** Get user name in glist.
+ * @param self Object pointer
+ * @param index the user name index
+ * @param username user name string
+ * @@return TRUE, if get the user name. FALSE, if not
+ */
+gboolean g_web_get_glist_item(GWeb *self, guint index, gchar **username);
+
 /** Destroy object.
   * @param self Object pointer
   */
