@@ -85,6 +85,18 @@ g_web_get_pref (GWeb *self, gpointer type, const gchar* name, gpointer value)
 	return G_WEB_GET_CLASS (self)->web_get_pref (self, type, name, value);
 }
 
+gboolean
+g_web_set_glist_select_item(GWeb *self, gint select)
+{
+	return G_WEB_GET_CLASS (self)->web_set_glist_select_item (self, select);
+}
+
+gboolean
+g_web_get_glist_item(GWeb *self, guint index, gchar **username)
+{
+	return G_WEB_GET_CLASS (self)->web_get_glist_item (self, index, username);
+}
+
 GWebTransferItem*
 g_web_new_web_transfer_item (GWeb *self, const gchar* url, const gchar* filename)
 {
